/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the
 * GNU Lesser General Public License as published by the Free Software Foundation; either version
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */

package it.tref.liferay.mapit.map.service.impl;

import it.tref.liferay.mapit.map.model.Plugin;
import it.tref.liferay.mapit.map.service.base.PluginLocalServiceBaseImpl;

import java.util.Date;
import java.util.List;

import com.liferay.portal.kernel.exception.SystemException;

/**
 * The implementation of the plugin local service.
 * 
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun
 * ServiceBuilder to copy their definitions into the
 * {@link it.tref.liferay.mapit.map.service.PluginLocalService} interface.
 * 
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the
 * propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 * 
 * @author
 * @see it.tref.liferay.mapit.map.service.base.PluginLocalServiceBaseImpl
 * @see it.tref.liferay.mapit.map.service.PluginLocalServiceUtil
 */
public class PluginLocalServiceImpl extends PluginLocalServiceBaseImpl {
  /*
   * NOTE FOR DEVELOPERS:
   * 
   * Never reference this interface directly. Always use {@link
   * it.tref.liferay.mapit.map.service.PluginLocalServiceUtil} to access the plugin local service.
   */

  public Plugin addPlugin(String name, String version, String mapItVersion, String context, boolean active)
      throws SystemException {

    Date now = new Date();

    Plugin plugin = createPlugin(counterLocalService.increment(Plugin.class.getName()));

    plugin.setCreateDate(now);
    plugin.setModifiedDate(now);

    plugin.setName(name);
    plugin.setVersion(version);
    plugin.setMapItVersion(mapItVersion);
    plugin.setContext(context);

    plugin.setActive(active);

    return addPlugin(plugin);
  }

  public Plugin updatePlugin(long pluginId, String name, String version, String mapItVersion, boolean active)
      throws SystemException {

    Plugin plugin = pluginLocalService.fetchPlugin(pluginId);

    plugin.setModifiedDate(new Date());

    plugin.setName(name);
    plugin.setVersion(version);
    plugin.setMapItVersion(mapItVersion);
    plugin.setActive(active);

    return updatePlugin(plugin);
  }

  public Plugin updatePlugin(long pluginId, boolean active) throws SystemException {

    Plugin plugin = pluginLocalService.fetchPlugin(pluginId);

    plugin.setModifiedDate(new Date());

    plugin.setActive(active);

    return updatePlugin(plugin);
  }

  public Plugin getPlugin(String context) throws SystemException {
    return pluginPersistence.fetchByContext(context);
  }

  public List<Plugin> getActivePlugins(int start, int end) throws SystemException {
    return pluginPersistence.findByActive(true, start, end);
  }
}
